Class: TrophyApiClient::AchievementWithStatsResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/trophy_api_client/types/achievement_with_stats_response.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(completions:, rarity:, id:, name:, trigger:, user_attributes:, description: OMIT, badge_url: OMIT, key: OMIT, streak_length: OMIT, achievement_ids: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, event_attribute: OMIT, event_attributes: OMIT, additional_properties: nil) ⇒ TrophyApiClient::AchievementWithStatsResponse

Parameters:

  • completions (Integer)

    The number of users who have completed this achievement.

  • rarity (Float)

    The percentage of all users who have completed this achievement.

  • id (String)

    The unique ID of the achievement.

  • name (String)

    The name of this achievement.

  • trigger (TrophyApiClient::AchievementResponseTrigger)

    The trigger of the achievement.

  • description (String) (defaults to: OMIT)

    The description of this achievement.

  • badge_url (String) (defaults to: OMIT)

    The URL of the badge image for the achievement, if one has been uploaded.

  • key (String) (defaults to: OMIT)

    The key used to reference this achievement in the API (only applicable if trigger = ‘api’)

  • streak_length (Integer) (defaults to: OMIT)

    The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’)

  • achievement_ids (Array<String>) (defaults to: OMIT)

    The IDs of the prerequisite achievements that must be completed to earn this achievement (only applicable if trigger = ‘achievement’)

  • metric_id (String) (defaults to: OMIT)

    The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’)

  • metric_value (Float) (defaults to: OMIT)

    The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’)

  • metric_name (String) (defaults to: OMIT)

    The name of the metric associated with this achievement (only applicable if trigger = ‘metric’)

  • user_attributes (Array<TrophyApiClient::AchievementResponseUserAttributesItem>)

    User attribute filters that must be met for this achievement to be completed.

  • event_attribute (TrophyApiClient::AchievementResponseEventAttribute) (defaults to: OMIT)

    Deprecated. Event attribute filter that must be met for this achievement to be completed. Only present if the achievement has an event filter configured.

  • event_attributes (Array<TrophyApiClient::AchievementResponseEventAttributesItem>) (defaults to: OMIT)

    Event attribute filters that must be met for this achievement to be completed. Omitted for non-metric achievements.

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 86

def initialize(completions:, rarity:, id:, name:, trigger:, user_attributes:, description: OMIT, badge_url: OMIT, key: OMIT,
               streak_length: OMIT, achievement_ids: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, event_attribute: OMIT, event_attributes: OMIT, additional_properties: nil)
  @completions = completions
  @rarity = rarity
  @id = id
  @name = name
  @trigger = trigger
  @description = description if description != OMIT
  @badge_url = badge_url if badge_url != OMIT
  @key = key if key != OMIT
  @streak_length = streak_length if streak_length != OMIT
  @achievement_ids = achievement_ids if achievement_ids != OMIT
  @metric_id = metric_id if metric_id != OMIT
  @metric_value = metric_value if metric_value != OMIT
  @metric_name = metric_name if metric_name != OMIT
  @user_attributes = user_attributes
  @event_attribute = event_attribute if event_attribute != OMIT
  @event_attributes = event_attributes if event_attributes != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "completions": completions,
    "rarity": rarity,
    "id": id,
    "name": name,
    "trigger": trigger,
    "description": description,
    "badgeUrl": badge_url,
    "key": key,
    "streakLength": streak_length,
    "achievementIds": achievement_ids,
    "metricId": metric_id,
    "metricValue": metric_value,
    "metricName": metric_name,
    "userAttributes": user_attributes,
    "eventAttribute": event_attribute,
    "eventAttributes": event_attributes
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#achievement_idsArray<String> (readonly)

Returns The IDs of the prerequisite achievements that must be completed to earn this achievement (only applicable if trigger = ‘achievement’).

Returns:

  • (Array<String>)

    The IDs of the prerequisite achievements that must be completed to earn this achievement (only applicable if trigger = ‘achievement’)



34
35
36
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 34

def achievement_ids
  @achievement_ids
end

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



53
54
55
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 53

def additional_properties
  @additional_properties
end

#badge_urlString (readonly)

Returns The URL of the badge image for the achievement, if one has been uploaded.

Returns:

  • (String)

    The URL of the badge image for the achievement, if one has been uploaded.



25
26
27
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 25

def badge_url
  @badge_url
end

#completionsInteger (readonly)

Returns The number of users who have completed this achievement.

Returns:

  • (Integer)

    The number of users who have completed this achievement.



13
14
15
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 13

def completions
  @completions
end

#descriptionString (readonly)

Returns The description of this achievement.

Returns:

  • (String)

    The description of this achievement.



23
24
25
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 23

def description
  @description
end

#event_attributeTrophyApiClient::AchievementResponseEventAttribute (readonly)

Returns Deprecated. Event attribute filter that must be met for this achievement to be completed. Only present if the achievement has an event filter configured.

Returns:



48
49
50
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 48

def event_attribute
  @event_attribute
end

#event_attributesArray<TrophyApiClient::AchievementResponseEventAttributesItem> (readonly)

Returns Event attribute filters that must be met for this achievement to be completed. Omitted for non-metric achievements.

Returns:



51
52
53
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 51

def event_attributes
  @event_attributes
end

#idString (readonly)

Returns The unique ID of the achievement.

Returns:

  • (String)

    The unique ID of the achievement.



17
18
19
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 17

def id
  @id
end

#keyString (readonly)

Returns The key used to reference this achievement in the API (only applicable if trigger = ‘api’).

Returns:

  • (String)

    The key used to reference this achievement in the API (only applicable if trigger = ‘api’)



28
29
30
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 28

def key
  @key
end

#metric_idString (readonly)

Returns The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’).

Returns:

  • (String)

    The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’)



37
38
39
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 37

def metric_id
  @metric_id
end

#metric_nameString (readonly)

Returns The name of the metric associated with this achievement (only applicable if trigger = ‘metric’).

Returns:

  • (String)

    The name of the metric associated with this achievement (only applicable if trigger = ‘metric’)



43
44
45
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 43

def metric_name
  @metric_name
end

#metric_valueFloat (readonly)

Returns The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’).

Returns:

  • (Float)

    The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’)



40
41
42
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 40

def metric_value
  @metric_value
end

#nameString (readonly)

Returns The name of this achievement.

Returns:

  • (String)

    The name of this achievement.



19
20
21
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 19

def name
  @name
end

#rarityFloat (readonly)

Returns The percentage of all users who have completed this achievement.

Returns:

  • (Float)

    The percentage of all users who have completed this achievement.



15
16
17
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 15

def rarity
  @rarity
end

#streak_lengthInteger (readonly)

Returns The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’).

Returns:

  • (Integer)

    The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’)



31
32
33
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 31

def streak_length
  @streak_length
end

#triggerTrophyApiClient::AchievementResponseTrigger (readonly)

Returns The trigger of the achievement.

Returns:



21
22
23
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 21

def trigger
  @trigger
end

#user_attributesArray<TrophyApiClient::AchievementResponseUserAttributesItem> (readonly)

Returns User attribute filters that must be met for this achievement to be completed.

Returns:



45
46
47
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 45

def user_attributes
  @user_attributes
end

Class Method Details

.from_json(json_object:) ⇒ TrophyApiClient::AchievementWithStatsResponse

Deserialize a JSON object to an instance of AchievementWithStatsResponse

Parameters:

  • json_object (String)

Returns:



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 131

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  completions = parsed_json["completions"]
  rarity = parsed_json["rarity"]
  id = parsed_json["id"]
  name = parsed_json["name"]
  trigger = parsed_json["trigger"]
  description = parsed_json["description"]
  badge_url = parsed_json["badgeUrl"]
  key = parsed_json["key"]
  streak_length = parsed_json["streakLength"]
  achievement_ids = parsed_json["achievementIds"]
  metric_id = parsed_json["metricId"]
  metric_value = parsed_json["metricValue"]
  metric_name = parsed_json["metricName"]
  user_attributes = parsed_json["userAttributes"]&.map do |item|
    item = item.to_json
    TrophyApiClient::AchievementResponseUserAttributesItem.from_json(json_object: item)
  end
  if parsed_json["eventAttribute"].nil?
    event_attribute = nil
  else
    event_attribute = parsed_json["eventAttribute"].to_json
    event_attribute = TrophyApiClient::AchievementResponseEventAttribute.from_json(json_object: event_attribute)
  end
  event_attributes = parsed_json["eventAttributes"]&.map do |item|
    item = item.to_json
    TrophyApiClient::AchievementResponseEventAttributesItem.from_json(json_object: item)
  end
  new(
    completions: completions,
    rarity: rarity,
    id: id,
    name: name,
    trigger: trigger,
    description: description,
    badge_url: badge_url,
    key: key,
    streak_length: streak_length,
    achievement_ids: achievement_ids,
    metric_id: metric_id,
    metric_value: metric_value,
    metric_name: metric_name,
    user_attributes: user_attributes,
    event_attribute: event_attribute,
    event_attributes: event_attributes,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 195

def self.validate_raw(obj:)
  obj.completions.is_a?(Integer) != false || raise("Passed value for field obj.completions is not the expected type, validation failed.")
  obj.rarity.is_a?(Float) != false || raise("Passed value for field obj.rarity is not the expected type, validation failed.")
  obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.trigger.is_a?(TrophyApiClient::AchievementResponseTrigger) != false || raise("Passed value for field obj.trigger is not the expected type, validation failed.")
  obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.")
  obj.badge_url&.is_a?(String) != false || raise("Passed value for field obj.badge_url is not the expected type, validation failed.")
  obj.key&.is_a?(String) != false || raise("Passed value for field obj.key is not the expected type, validation failed.")
  obj.streak_length&.is_a?(Integer) != false || raise("Passed value for field obj.streak_length is not the expected type, validation failed.")
  obj.achievement_ids&.is_a?(Array) != false || raise("Passed value for field obj.achievement_ids is not the expected type, validation failed.")
  obj.metric_id&.is_a?(String) != false || raise("Passed value for field obj.metric_id is not the expected type, validation failed.")
  obj.metric_value&.is_a?(Float) != false || raise("Passed value for field obj.metric_value is not the expected type, validation failed.")
  obj.metric_name&.is_a?(String) != false || raise("Passed value for field obj.metric_name is not the expected type, validation failed.")
  obj.user_attributes.is_a?(Array) != false || raise("Passed value for field obj.user_attributes is not the expected type, validation failed.")
  obj.event_attribute.nil? || TrophyApiClient::AchievementResponseEventAttribute.validate_raw(obj: obj.event_attribute)
  obj.event_attributes&.is_a?(Array) != false || raise("Passed value for field obj.event_attributes is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of AchievementWithStatsResponse to a JSON object

Returns:

  • (String)


185
186
187
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 185

def to_json(*_args)
  @_field_set&.to_json
end