Class: TrophyApiClient::AdminPointsTriggerEventAttributesItem

Inherits:
Object
  • Object
show all
Defined in:
lib/trophy_api_client/types/admin_points_trigger_event_attributes_item.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attribute_id:, attribute_value:, additional_properties: nil) ⇒ TrophyApiClient::AdminPointsTriggerEventAttributesItem

Parameters:

  • attribute_id (String)
  • attribute_value (String)
  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



24
25
26
27
28
29
# File 'lib/trophy_api_client/types/admin_points_trigger_event_attributes_item.rb', line 24

def initialize(attribute_id:, attribute_value:, additional_properties: nil)
  @attribute_id = attribute_id
  @attribute_value = attribute_value
  @additional_properties = additional_properties
  @_field_set = { "attributeId": attribute_id, "attributeValue": attribute_value }
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



13
14
15
# File 'lib/trophy_api_client/types/admin_points_trigger_event_attributes_item.rb', line 13

def additional_properties
  @additional_properties
end

#attribute_idString (readonly)

Returns:

  • (String)


9
10
11
# File 'lib/trophy_api_client/types/admin_points_trigger_event_attributes_item.rb', line 9

def attribute_id
  @attribute_id
end

#attribute_valueString (readonly)

Returns:

  • (String)


11
12
13
# File 'lib/trophy_api_client/types/admin_points_trigger_event_attributes_item.rb', line 11

def attribute_value
  @attribute_value
end

Class Method Details

.from_json(json_object:) ⇒ TrophyApiClient::AdminPointsTriggerEventAttributesItem

Deserialize a JSON object to an instance of

AdminPointsTriggerEventAttributesItem

Parameters:

  • json_object (String)

Returns:



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/trophy_api_client/types/admin_points_trigger_event_attributes_item.rb', line 36

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  attribute_id = parsed_json["attributeId"]
  attribute_value = parsed_json["attributeValue"]
  new(
    attribute_id: attribute_id,
    attribute_value: attribute_value,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


61
62
63
64
# File 'lib/trophy_api_client/types/admin_points_trigger_event_attributes_item.rb', line 61

def self.validate_raw(obj:)
  obj.attribute_id.is_a?(String) != false || raise("Passed value for field obj.attribute_id is not the expected type, validation failed.")
  obj.attribute_value.is_a?(String) != false || raise("Passed value for field obj.attribute_value is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of AdminPointsTriggerEventAttributesItem to a JSON object

Returns:

  • (String)


51
52
53
# File 'lib/trophy_api_client/types/admin_points_trigger_event_attributes_item.rb', line 51

def to_json(*_args)
  @_field_set&.to_json
end