Class: TrophyApiClient::CreateTenantRequestItem
- Inherits:
-
Object
- Object
- TrophyApiClient::CreateTenantRequestItem
- Defined in:
- lib/trophy_api_client/types/create_tenant_request_item.rb
Overview
A tenant to create.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#customer_id ⇒ String
readonly
The external customer ID.
-
#name ⇒ String
readonly
Human-readable name for the tenant.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::CreateTenantRequestItem
Deserialize a JSON object to an instance of CreateTenantRequestItem.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(customer_id:, name:, additional_properties: nil) ⇒ TrophyApiClient::CreateTenantRequestItem constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of CreateTenantRequestItem to a JSON object.
Constructor Details
#initialize(customer_id:, name:, additional_properties: nil) ⇒ TrophyApiClient::CreateTenantRequestItem
25 26 27 28 29 30 |
# File 'lib/trophy_api_client/types/create_tenant_request_item.rb', line 25 def initialize(customer_id:, name:, additional_properties: nil) @customer_id = customer_id @name = name @additional_properties = additional_properties @_field_set = { "customerId": customer_id, "name": name } end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
14 15 16 |
# File 'lib/trophy_api_client/types/create_tenant_request_item.rb', line 14 def additional_properties @additional_properties end |
#customer_id ⇒ String (readonly)
Returns The external customer ID. Must be unique within the environment.
10 11 12 |
# File 'lib/trophy_api_client/types/create_tenant_request_item.rb', line 10 def customer_id @customer_id end |
#name ⇒ String (readonly)
Returns Human-readable name for the tenant.
12 13 14 |
# File 'lib/trophy_api_client/types/create_tenant_request_item.rb', line 12 def name @name end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::CreateTenantRequestItem
Deserialize a JSON object to an instance of CreateTenantRequestItem
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/trophy_api_client/types/create_tenant_request_item.rb', line 36 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) customer_id = parsed_json["customerId"] name = parsed_json["name"] new( customer_id: customer_id, name: name, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
61 62 63 64 |
# File 'lib/trophy_api_client/types/create_tenant_request_item.rb', line 61 def self.validate_raw(obj:) obj.customer_id.is_a?(String) != false || raise("Passed value for field obj.customer_id is not the expected type, validation failed.") obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of CreateTenantRequestItem to a JSON object
51 52 53 |
# File 'lib/trophy_api_client/types/create_tenant_request_item.rb', line 51 def to_json(*_args) @_field_set&.to_json end |