Class: TrophyApiClient::MetricAchievementResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/trophy_api_client/types/metric_achievement_response.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(trigger:, metric_id:, metric_value:, metric_name:, id:, name:, badge_url: OMIT, key: OMIT, achieved_at: OMIT, additional_properties: nil) ⇒ TrophyApiClient::MetricAchievementResponse

Parameters:

  • trigger (String)

    The trigger of the achievement, in this case always ‘metric’.

  • metric_id (String)

    The ID of the metric associated with this achievement, if any.

  • metric_value (Float)

    The value of the metric required to complete the achievement, if this achievement is associated with a metric.

  • metric_name (String)

    The name of the metric associated with this achievement, if any.

  • id (String)

    The unique ID of the achievement.

  • name (String)

    The name of this achievement.

  • badge_url (String) (defaults to: OMIT)

    The URL of the badge image for the achievement, if one has been uploaded.

  • key (String) (defaults to: OMIT)

    The key used to reference this achievement in the API.

  • achieved_at (DateTime) (defaults to: OMIT)

    The date and time the achievement was completed, in ISO 8601 format.

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 48

def initialize(trigger:, metric_id:, metric_value:, metric_name:, id:, name:, badge_url: OMIT, key: OMIT,
               achieved_at: OMIT, additional_properties: nil)
  @trigger = trigger
  @metric_id = metric_id
  @metric_value = metric_value
  @metric_name = metric_name
  @id = id
  @name = name
  @badge_url = badge_url if badge_url != OMIT
  @key = key if key != OMIT
  @achieved_at = achieved_at if achieved_at != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "trigger": trigger,
    "metricId": metric_id,
    "metricValue": metric_value,
    "metricName": metric_name,
    "id": id,
    "name": name,
    "badgeUrl": badge_url,
    "key": key,
    "achievedAt": achieved_at
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#achieved_atDateTime (readonly)

Returns The date and time the achievement was completed, in ISO 8601 format.

Returns:

  • (DateTime)

    The date and time the achievement was completed, in ISO 8601 format.



27
28
29
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 27

def achieved_at
  @achieved_at
end

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



29
30
31
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 29

def additional_properties
  @additional_properties
end

#badge_urlString (readonly)

Returns The URL of the badge image for the achievement, if one has been uploaded.

Returns:

  • (String)

    The URL of the badge image for the achievement, if one has been uploaded.



23
24
25
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 23

def badge_url
  @badge_url
end

#idString (readonly)

Returns The unique ID of the achievement.

Returns:

  • (String)

    The unique ID of the achievement.



19
20
21
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 19

def id
  @id
end

#keyString (readonly)

Returns The key used to reference this achievement in the API.

Returns:

  • (String)

    The key used to reference this achievement in the API.



25
26
27
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 25

def key
  @key
end

#metric_idString (readonly)

Returns The ID of the metric associated with this achievement, if any.

Returns:

  • (String)

    The ID of the metric associated with this achievement, if any.



12
13
14
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 12

def metric_id
  @metric_id
end

#metric_nameString (readonly)

Returns The name of the metric associated with this achievement, if any.

Returns:

  • (String)

    The name of the metric associated with this achievement, if any.



17
18
19
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 17

def metric_name
  @metric_name
end

#metric_valueFloat (readonly)

Returns The value of the metric required to complete the achievement, if this achievement is associated with a metric.

Returns:

  • (Float)

    The value of the metric required to complete the achievement, if this achievement is associated with a metric.



15
16
17
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 15

def metric_value
  @metric_value
end

#nameString (readonly)

Returns The name of this achievement.

Returns:

  • (String)

    The name of this achievement.



21
22
23
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 21

def name
  @name
end

#triggerString (readonly)

Returns The trigger of the achievement, in this case always ‘metric’.

Returns:

  • (String)

    The trigger of the achievement, in this case always ‘metric’.



10
11
12
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 10

def trigger
  @trigger
end

Class Method Details

.from_json(json_object:) ⇒ TrophyApiClient::MetricAchievementResponse

Deserialize a JSON object to an instance of MetricAchievementResponse

Parameters:

  • json_object (String)

Returns:



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 79

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  trigger = parsed_json["trigger"]
  metric_id = parsed_json["metricId"]
  metric_value = parsed_json["metricValue"]
  metric_name = parsed_json["metricName"]
  id = parsed_json["id"]
  name = parsed_json["name"]
  badge_url = parsed_json["badgeUrl"]
  key = parsed_json["key"]
  achieved_at = (DateTime.parse(parsed_json["achievedAt"]) unless parsed_json["achievedAt"].nil?)
  new(
    trigger: trigger,
    metric_id: metric_id,
    metric_value: metric_value,
    metric_name: metric_name,
    id: id,
    name: name,
    badge_url: badge_url,
    key: key,
    achieved_at: achieved_at,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


118
119
120
121
122
123
124
125
126
127
128
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 118

def self.validate_raw(obj:)
  obj.trigger.is_a?(String) != false || raise("Passed value for field obj.trigger is not the expected type, validation failed.")
  obj.metric_id.is_a?(String) != false || raise("Passed value for field obj.metric_id is not the expected type, validation failed.")
  obj.metric_value.is_a?(Float) != false || raise("Passed value for field obj.metric_value is not the expected type, validation failed.")
  obj.metric_name.is_a?(String) != false || raise("Passed value for field obj.metric_name is not the expected type, validation failed.")
  obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.badge_url&.is_a?(String) != false || raise("Passed value for field obj.badge_url is not the expected type, validation failed.")
  obj.key&.is_a?(String) != false || raise("Passed value for field obj.key is not the expected type, validation failed.")
  obj.achieved_at&.is_a?(DateTime) != false || raise("Passed value for field obj.achieved_at is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of MetricAchievementResponse to a JSON object

Returns:

  • (String)


108
109
110
# File 'lib/trophy_api_client/types/metric_achievement_response.rb', line 108

def to_json(*_args)
  @_field_set&.to_json
end