Class: TrophyApiClient::StreakMetricPreference
- Inherits:
-
Object
- Object
- TrophyApiClient::StreakMetricPreference
- Defined in:
- lib/trophy_api_client/types/streak_metric_preference.rb
Overview
Per-metric streak threshold override for a user.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#key ⇒ String
readonly
The metric key.
-
#threshold ⇒ Float
readonly
Minimum metric change in a streak period to count toward the streak.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::StreakMetricPreference
Deserialize a JSON object to an instance of StreakMetricPreference.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(key:, threshold:, additional_properties: nil) ⇒ TrophyApiClient::StreakMetricPreference constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of StreakMetricPreference to a JSON object.
Constructor Details
#initialize(key:, threshold:, additional_properties: nil) ⇒ TrophyApiClient::StreakMetricPreference
25 26 27 28 29 30 |
# File 'lib/trophy_api_client/types/streak_metric_preference.rb', line 25 def initialize(key:, threshold:, additional_properties: nil) @key = key @threshold = threshold @additional_properties = additional_properties @_field_set = { "key": key, "threshold": threshold } end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
14 15 16 |
# File 'lib/trophy_api_client/types/streak_metric_preference.rb', line 14 def additional_properties @additional_properties end |
#key ⇒ String (readonly)
Returns The metric key.
10 11 12 |
# File 'lib/trophy_api_client/types/streak_metric_preference.rb', line 10 def key @key end |
#threshold ⇒ Float (readonly)
Returns Minimum metric change in a streak period to count toward the streak.
12 13 14 |
# File 'lib/trophy_api_client/types/streak_metric_preference.rb', line 12 def threshold @threshold end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::StreakMetricPreference
Deserialize a JSON object to an instance of StreakMetricPreference
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/trophy_api_client/types/streak_metric_preference.rb', line 36 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) key = parsed_json["key"] threshold = parsed_json["threshold"] new( key: key, threshold: threshold, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
61 62 63 64 |
# File 'lib/trophy_api_client/types/streak_metric_preference.rb', line 61 def self.validate_raw(obj:) obj.key.is_a?(String) != false || raise("Passed value for field obj.key is not the expected type, validation failed.") obj.threshold.is_a?(Float) != false || raise("Passed value for field obj.threshold is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of StreakMetricPreference to a JSON object
51 52 53 |
# File 'lib/trophy_api_client/types/streak_metric_preference.rb', line 51 def to_json(*_args) @_field_set&.to_json end |