Class: TrophyApiClient::StreakResponse
- Inherits:
-
Object
- Object
- TrophyApiClient::StreakResponse
- Defined in:
- lib/trophy_api_client/types/streak_response.rb
Overview
An object representing the user’s streak.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#expires ⇒ String
readonly
The date the streak will expire if the user does not increment a metric.
-
#extended ⇒ DateTime
readonly
The timestamp the streak was most recently extended.
-
#freeze_auto_earn_amount ⇒ Integer
readonly
The amount of streak freezes the user will earn per interval.
-
#freeze_auto_earn_interval ⇒ Integer
readonly
The interval at which the user will earn streak freezes, in days.
-
#freezes ⇒ Integer
readonly
The number of available streak freezes.
-
#frequency ⇒ TrophyApiClient::StreakFrequency
readonly
The frequency of the streak.
-
#length ⇒ Integer
readonly
The length of the user’s current streak.
-
#max_freezes ⇒ Integer
readonly
The maximum number of streak freezes a user can have.
-
#period_end ⇒ String
readonly
The end date of the current streak period.
-
#period_start ⇒ String
readonly
The start date of the current streak period.
-
#started ⇒ String
readonly
The date the streak started.
-
#streak_history ⇒ Array<TrophyApiClient::StreakResponseStreakHistoryItem>
readonly
A list of the user’s past streak periods up through the current period.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::StreakResponse
Deserialize a JSON object to an instance of StreakResponse.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(streak_history:, length:, frequency:, extended: OMIT, started: OMIT, period_start: OMIT, period_end: OMIT, expires: OMIT, freezes: OMIT, max_freezes: OMIT, freeze_auto_earn_interval: OMIT, freeze_auto_earn_amount: OMIT, additional_properties: nil) ⇒ TrophyApiClient::StreakResponse constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of StreakResponse to a JSON object.
Constructor Details
#initialize(streak_history:, length:, frequency:, extended: OMIT, started: OMIT, period_start: OMIT, period_end: OMIT, expires: OMIT, freezes: OMIT, max_freezes: OMIT, freeze_auto_earn_interval: OMIT, freeze_auto_earn_amount: OMIT, additional_properties: nil) ⇒ TrophyApiClient::StreakResponse
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 70 def initialize(streak_history:, length:, frequency:, extended: OMIT, started: OMIT, period_start: OMIT, period_end: OMIT, expires: OMIT, freezes: OMIT, max_freezes: OMIT, freeze_auto_earn_interval: OMIT, freeze_auto_earn_amount: OMIT, additional_properties: nil) @extended = extended if extended != OMIT @streak_history = streak_history @length = length @frequency = frequency @started = started if started != OMIT @period_start = period_start if period_start != OMIT @period_end = period_end if period_end != OMIT @expires = expires if expires != OMIT @freezes = freezes if freezes != OMIT @max_freezes = max_freezes if max_freezes != OMIT @freeze_auto_earn_interval = freeze_auto_earn_interval if freeze_auto_earn_interval != OMIT @freeze_auto_earn_amount = freeze_auto_earn_amount if freeze_auto_earn_amount != OMIT @additional_properties = additional_properties @_field_set = { "extended": extended, "streakHistory": streak_history, "length": length, "frequency": frequency, "started": started, "periodStart": period_start, "periodEnd": period_end, "expires": expires, "freezes": freezes, "maxFreezes": max_freezes, "freezeAutoEarnInterval": freeze_auto_earn_interval, "freezeAutoEarnAmount": freeze_auto_earn_amount }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
43 44 45 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 43 def additional_properties @additional_properties end |
#expires ⇒ String (readonly)
Returns The date the streak will expire if the user does not increment a metric.
29 30 31 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 29 def expires @expires end |
#extended ⇒ DateTime (readonly)
Returns The timestamp the streak was most recently extended. Null if the streak is not active.
14 15 16 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 14 def extended @extended end |
#freeze_auto_earn_amount ⇒ Integer (readonly)
Returns The amount of streak freezes the user will earn per interval. Only present if the organization has enabled streak freeze auto-earn.
41 42 43 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 41 def freeze_auto_earn_amount @freeze_auto_earn_amount end |
#freeze_auto_earn_interval ⇒ Integer (readonly)
Returns The interval at which the user will earn streak freezes, in days. Only present if the organization has enabled streak freeze auto-earn.
38 39 40 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 38 def freeze_auto_earn_interval @freeze_auto_earn_interval end |
#freezes ⇒ Integer (readonly)
Returns The number of available streak freezes. Only present if the organization has enabled streak freezes.
32 33 34 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 32 def freezes @freezes end |
#frequency ⇒ TrophyApiClient::StreakFrequency (readonly)
Returns The frequency of the streak.
21 22 23 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 21 def frequency @frequency end |
#length ⇒ Integer (readonly)
Returns The length of the user’s current streak.
19 20 21 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 19 def length @length end |
#max_freezes ⇒ Integer (readonly)
Returns The maximum number of streak freezes a user can have. Only present if the organization has enabled streak freezes.
35 36 37 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 35 def max_freezes @max_freezes end |
#period_end ⇒ String (readonly)
Returns The end date of the current streak period.
27 28 29 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 27 def period_end @period_end end |
#period_start ⇒ String (readonly)
Returns The start date of the current streak period.
25 26 27 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 25 def period_start @period_start end |
#started ⇒ String (readonly)
Returns The date the streak started.
23 24 25 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 23 def started @started end |
#streak_history ⇒ Array<TrophyApiClient::StreakResponseStreakHistoryItem> (readonly)
Returns A list of the user’s past streak periods up through the current period. Each period includes the start and end dates and the length of the streak.
17 18 19 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 17 def streak_history @streak_history end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::StreakResponse
Deserialize a JSON object to an instance of StreakResponse
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 107 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) extended = (DateTime.parse(parsed_json["extended"]) unless parsed_json["extended"].nil?) streak_history = parsed_json["streakHistory"]&.map do |item| item = item.to_json TrophyApiClient::StreakResponseStreakHistoryItem.from_json(json_object: item) end length = parsed_json["length"] frequency = parsed_json["frequency"] started = parsed_json["started"] period_start = parsed_json["periodStart"] period_end = parsed_json["periodEnd"] expires = parsed_json["expires"] freezes = parsed_json["freezes"] max_freezes = parsed_json["maxFreezes"] freeze_auto_earn_interval = parsed_json["freezeAutoEarnInterval"] freeze_auto_earn_amount = parsed_json["freezeAutoEarnAmount"] new( extended: extended, streak_history: streak_history, length: length, frequency: frequency, started: started, period_start: period_start, period_end: period_end, expires: expires, freezes: freezes, max_freezes: max_freezes, freeze_auto_earn_interval: freeze_auto_earn_interval, freeze_auto_earn_amount: freeze_auto_earn_amount, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 155 def self.validate_raw(obj:) obj.extended&.is_a?(DateTime) != false || raise("Passed value for field obj.extended is not the expected type, validation failed.") obj.streak_history.is_a?(Array) != false || raise("Passed value for field obj.streak_history is not the expected type, validation failed.") obj.length.is_a?(Integer) != false || raise("Passed value for field obj.length is not the expected type, validation failed.") obj.frequency.is_a?(TrophyApiClient::StreakFrequency) != false || raise("Passed value for field obj.frequency is not the expected type, validation failed.") obj.started&.is_a?(String) != false || raise("Passed value for field obj.started is not the expected type, validation failed.") obj.period_start&.is_a?(String) != false || raise("Passed value for field obj.period_start is not the expected type, validation failed.") obj.period_end&.is_a?(String) != false || raise("Passed value for field obj.period_end is not the expected type, validation failed.") obj.expires&.is_a?(String) != false || raise("Passed value for field obj.expires is not the expected type, validation failed.") obj.freezes&.is_a?(Integer) != false || raise("Passed value for field obj.freezes is not the expected type, validation failed.") obj.max_freezes&.is_a?(Integer) != false || raise("Passed value for field obj.max_freezes is not the expected type, validation failed.") obj.freeze_auto_earn_interval&.is_a?(Integer) != false || raise("Passed value for field obj.freeze_auto_earn_interval is not the expected type, validation failed.") obj.freeze_auto_earn_amount&.is_a?(Integer) != false || raise("Passed value for field obj.freeze_auto_earn_amount is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of StreakResponse to a JSON object
145 146 147 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 145 def to_json(*_args) @_field_set&.to_json end |