Class: TrophyApiClient::AchievementResponse
- Inherits:
-
Object
- Object
- TrophyApiClient::AchievementResponse
- Defined in:
- lib/trophy_api_client/types/achievement_response.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#achievement_ids ⇒ Array<String>
readonly
The IDs of the prerequisite achievements that must be completed to earn this achievement (only applicable if trigger = ‘achievement’).
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#badge_url ⇒ String
readonly
The URL of the badge image for the achievement, if one has been uploaded.
-
#description ⇒ String
readonly
The description of this achievement.
-
#event_attribute ⇒ TrophyApiClient::AchievementResponseEventAttribute
readonly
Deprecated.
-
#event_attributes ⇒ Array<TrophyApiClient::AchievementResponseEventAttributesItem>
readonly
Event attribute filters that must be met for this achievement to be completed.
-
#id ⇒ String
readonly
The unique ID of the achievement.
-
#key ⇒ String
readonly
The key used to reference this achievement in the API (only applicable if trigger = ‘api’).
-
#metric_id ⇒ String
readonly
The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’).
-
#metric_name ⇒ String
readonly
The name of the metric associated with this achievement (only applicable if trigger = ‘metric’).
-
#metric_value ⇒ Float
readonly
The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’).
-
#name ⇒ String
readonly
The name of this achievement.
-
#streak_length ⇒ Integer
readonly
The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’).
-
#trigger ⇒ TrophyApiClient::AchievementResponseTrigger
readonly
The trigger of the achievement.
-
#user_attributes ⇒ Array<TrophyApiClient::AchievementResponseUserAttributesItem>
readonly
User attribute filters that must be met for this achievement to be completed.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::AchievementResponse
Deserialize a JSON object to an instance of AchievementResponse.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(id:, name:, trigger:, user_attributes:, description: OMIT, badge_url: OMIT, key: OMIT, streak_length: OMIT, achievement_ids: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, event_attribute: OMIT, event_attributes: OMIT, additional_properties: nil) ⇒ TrophyApiClient::AchievementResponse constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of AchievementResponse to a JSON object.
Constructor Details
#initialize(id:, name:, trigger:, user_attributes:, description: OMIT, badge_url: OMIT, key: OMIT, streak_length: OMIT, achievement_ids: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, event_attribute: OMIT, event_attributes: OMIT, additional_properties: nil) ⇒ TrophyApiClient::AchievementResponse
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 80 def initialize(id:, name:, trigger:, user_attributes:, description: OMIT, badge_url: OMIT, key: OMIT, streak_length: OMIT, achievement_ids: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, event_attribute: OMIT, event_attributes: OMIT, additional_properties: nil) @id = id @name = name @trigger = trigger @description = description if description != OMIT @badge_url = badge_url if badge_url != OMIT @key = key if key != OMIT @streak_length = streak_length if streak_length != OMIT @achievement_ids = achievement_ids if achievement_ids != OMIT @metric_id = metric_id if metric_id != OMIT @metric_value = metric_value if metric_value != OMIT @metric_name = metric_name if metric_name != OMIT @user_attributes = user_attributes @event_attribute = event_attribute if event_attribute != OMIT @event_attributes = event_attributes if event_attributes != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "name": name, "trigger": trigger, "description": description, "badgeUrl": badge_url, "key": key, "streakLength": streak_length, "achievementIds": achievement_ids, "metricId": metric_id, "metricValue": metric_value, "metricName": metric_name, "userAttributes": user_attributes, "eventAttribute": event_attribute, "eventAttributes": event_attributes }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#achievement_ids ⇒ Array<String> (readonly)
Returns The IDs of the prerequisite achievements that must be completed to earn this achievement (only applicable if trigger = ‘achievement’).
30 31 32 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 30 def achievement_ids @achievement_ids end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
49 50 51 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 49 def additional_properties @additional_properties end |
#badge_url ⇒ String (readonly)
Returns The URL of the badge image for the achievement, if one has been uploaded.
21 22 23 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 21 def badge_url @badge_url end |
#description ⇒ String (readonly)
Returns The description of this achievement.
19 20 21 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 19 def description @description end |
#event_attribute ⇒ TrophyApiClient::AchievementResponseEventAttribute (readonly)
Returns Deprecated. Event attribute filter that must be met for this achievement to be completed. Only present if the achievement has an event filter configured.
44 45 46 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 44 def event_attribute @event_attribute end |
#event_attributes ⇒ Array<TrophyApiClient::AchievementResponseEventAttributesItem> (readonly)
Returns Event attribute filters that must be met for this achievement to be completed. Omitted for non-metric achievements.
47 48 49 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 47 def event_attributes @event_attributes end |
#id ⇒ String (readonly)
Returns The unique ID of the achievement.
13 14 15 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 13 def id @id end |
#key ⇒ String (readonly)
Returns The key used to reference this achievement in the API (only applicable if trigger = ‘api’).
24 25 26 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 24 def key @key end |
#metric_id ⇒ String (readonly)
Returns The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’).
33 34 35 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 33 def metric_id @metric_id end |
#metric_name ⇒ String (readonly)
Returns The name of the metric associated with this achievement (only applicable if trigger = ‘metric’).
39 40 41 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 39 def metric_name @metric_name end |
#metric_value ⇒ Float (readonly)
Returns The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’).
36 37 38 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 36 def metric_value @metric_value end |
#name ⇒ String (readonly)
Returns The name of this achievement.
15 16 17 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 15 def name @name end |
#streak_length ⇒ Integer (readonly)
Returns The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’).
27 28 29 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 27 def streak_length @streak_length end |
#trigger ⇒ TrophyApiClient::AchievementResponseTrigger (readonly)
Returns The trigger of the achievement.
17 18 19 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 17 def trigger @trigger end |
#user_attributes ⇒ Array<TrophyApiClient::AchievementResponseUserAttributesItem> (readonly)
Returns User attribute filters that must be met for this achievement to be completed.
41 42 43 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 41 def user_attributes @user_attributes end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::AchievementResponse
Deserialize a JSON object to an instance of AchievementResponse
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 121 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] name = parsed_json["name"] trigger = parsed_json["trigger"] description = parsed_json["description"] badge_url = parsed_json["badgeUrl"] key = parsed_json["key"] streak_length = parsed_json["streakLength"] achievement_ids = parsed_json["achievementIds"] metric_id = parsed_json["metricId"] metric_value = parsed_json["metricValue"] metric_name = parsed_json["metricName"] user_attributes = parsed_json["userAttributes"]&.map do |item| item = item.to_json TrophyApiClient::AchievementResponseUserAttributesItem.from_json(json_object: item) end if parsed_json["eventAttribute"].nil? event_attribute = nil else event_attribute = parsed_json["eventAttribute"].to_json event_attribute = TrophyApiClient::AchievementResponseEventAttribute.from_json(json_object: event_attribute) end event_attributes = parsed_json["eventAttributes"]&.map do |item| item = item.to_json TrophyApiClient::AchievementResponseEventAttributesItem.from_json(json_object: item) end new( id: id, name: name, trigger: trigger, description: description, badge_url: badge_url, key: key, streak_length: streak_length, achievement_ids: achievement_ids, metric_id: metric_id, metric_value: metric_value, metric_name: metric_name, user_attributes: user_attributes, event_attribute: event_attribute, event_attributes: event_attributes, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 181 def self.validate_raw(obj:) obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.trigger.is_a?(TrophyApiClient::AchievementResponseTrigger) != false || raise("Passed value for field obj.trigger is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.badge_url&.is_a?(String) != false || raise("Passed value for field obj.badge_url is not the expected type, validation failed.") obj.key&.is_a?(String) != false || raise("Passed value for field obj.key is not the expected type, validation failed.") obj.streak_length&.is_a?(Integer) != false || raise("Passed value for field obj.streak_length is not the expected type, validation failed.") obj.achievement_ids&.is_a?(Array) != false || raise("Passed value for field obj.achievement_ids is not the expected type, validation failed.") obj.metric_id&.is_a?(String) != false || raise("Passed value for field obj.metric_id is not the expected type, validation failed.") obj.metric_value&.is_a?(Float) != false || raise("Passed value for field obj.metric_value is not the expected type, validation failed.") obj.metric_name&.is_a?(String) != false || raise("Passed value for field obj.metric_name is not the expected type, validation failed.") obj.user_attributes.is_a?(Array) != false || raise("Passed value for field obj.user_attributes is not the expected type, validation failed.") obj.event_attribute.nil? || TrophyApiClient::AchievementResponseEventAttribute.validate_raw(obj: obj.event_attribute) obj.event_attributes&.is_a?(Array) != false || raise("Passed value for field obj.event_attributes is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of AchievementResponse to a JSON object
171 172 173 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 171 def to_json(*_args) @_field_set&.to_json end |