Class: TrophyApiClient::AchievementResponse
- Inherits:
-
Object
- Object
- TrophyApiClient::AchievementResponse
- Defined in:
- lib/trophy_api_client/types/achievement_response.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#badge_url ⇒ String
readonly
The URL of the badge image for the achievement, if one has been uploaded.
-
#current_streak ⇒ TrophyApiClient::MetricEventStreakResponse
readonly
The user’s current streak for the metric, if the metric has streaks enabled.
-
#description ⇒ String
readonly
The description of this achievement.
-
#id ⇒ String
readonly
The unique ID of the achievement.
-
#key ⇒ String
readonly
The key used to reference this achievement in the API (only applicable if trigger = ‘api’).
-
#metric_id ⇒ String
readonly
The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’).
-
#metric_name ⇒ String
readonly
The name of the metric associated with this achievement (only applicable if trigger = ‘metric’).
-
#metric_value ⇒ Float
readonly
The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’).
-
#name ⇒ String
readonly
The name of this achievement.
-
#streak_length ⇒ Integer
readonly
The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’).
-
#trigger ⇒ TrophyApiClient::AchievementResponseTrigger
readonly
The trigger of the achievement.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::AchievementResponse
Deserialize a JSON object to an instance of AchievementResponse.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(id:, name:, trigger:, description: OMIT, badge_url: OMIT, key: OMIT, streak_length: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, current_streak: OMIT, additional_properties: nil) ⇒ TrophyApiClient::AchievementResponse constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of AchievementResponse to a JSON object.
Constructor Details
#initialize(id:, name:, trigger:, description: OMIT, badge_url: OMIT, key: OMIT, streak_length: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, current_streak: OMIT, additional_properties: nil) ⇒ TrophyApiClient::AchievementResponse
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 63 def initialize(id:, name:, trigger:, description: OMIT, badge_url: OMIT, key: OMIT, streak_length: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, current_streak: OMIT, additional_properties: nil) @id = id @name = name @trigger = trigger @description = description if description != OMIT @badge_url = badge_url if badge_url != OMIT @key = key if key != OMIT @streak_length = streak_length if streak_length != OMIT @metric_id = metric_id if metric_id != OMIT @metric_value = metric_value if metric_value != OMIT @metric_name = metric_name if metric_name != OMIT @current_streak = current_streak if current_streak != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "name": name, "trigger": trigger, "description": description, "badgeUrl": badge_url, "key": key, "streakLength": streak_length, "metricId": metric_id, "metricValue": metric_value, "metricName": metric_name, "currentStreak": current_streak }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
38 39 40 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 38 def additional_properties @additional_properties end |
#badge_url ⇒ String (readonly)
Returns The URL of the badge image for the achievement, if one has been uploaded.
19 20 21 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 19 def badge_url @badge_url end |
#current_streak ⇒ TrophyApiClient::MetricEventStreakResponse (readonly)
Returns The user’s current streak for the metric, if the metric has streaks enabled.
36 37 38 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 36 def current_streak @current_streak end |
#description ⇒ String (readonly)
Returns The description of this achievement.
17 18 19 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 17 def description @description end |
#id ⇒ String (readonly)
Returns The unique ID of the achievement.
11 12 13 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 11 def id @id end |
#key ⇒ String (readonly)
Returns The key used to reference this achievement in the API (only applicable if trigger = ‘api’).
22 23 24 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 22 def key @key end |
#metric_id ⇒ String (readonly)
Returns The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’).
28 29 30 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 28 def metric_id @metric_id end |
#metric_name ⇒ String (readonly)
Returns The name of the metric associated with this achievement (only applicable if trigger = ‘metric’).
34 35 36 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 34 def metric_name @metric_name end |
#metric_value ⇒ Float (readonly)
Returns The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’).
31 32 33 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 31 def metric_value @metric_value end |
#name ⇒ String (readonly)
Returns The name of this achievement.
13 14 15 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 13 def name @name end |
#streak_length ⇒ Integer (readonly)
Returns The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’).
25 26 27 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 25 def streak_length @streak_length end |
#trigger ⇒ TrophyApiClient::AchievementResponseTrigger (readonly)
Returns The trigger of the achievement.
15 16 17 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 15 def trigger @trigger end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::AchievementResponse
Deserialize a JSON object to an instance of AchievementResponse
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 98 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] name = parsed_json["name"] trigger = parsed_json["trigger"] description = parsed_json["description"] badge_url = parsed_json["badgeUrl"] key = parsed_json["key"] streak_length = parsed_json["streakLength"] metric_id = parsed_json["metricId"] metric_value = parsed_json["metricValue"] metric_name = parsed_json["metricName"] if parsed_json["currentStreak"].nil? current_streak = nil else current_streak = parsed_json["currentStreak"].to_json current_streak = TrophyApiClient::MetricEventStreakResponse.from_json(json_object: current_streak) end new( id: id, name: name, trigger: trigger, description: description, badge_url: badge_url, key: key, streak_length: streak_length, metric_id: metric_id, metric_value: metric_value, metric_name: metric_name, current_streak: current_streak, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 146 def self.validate_raw(obj:) obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.trigger.is_a?(TrophyApiClient::AchievementResponseTrigger) != false || raise("Passed value for field obj.trigger is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.badge_url&.is_a?(String) != false || raise("Passed value for field obj.badge_url is not the expected type, validation failed.") obj.key&.is_a?(String) != false || raise("Passed value for field obj.key is not the expected type, validation failed.") obj.streak_length&.is_a?(Integer) != false || raise("Passed value for field obj.streak_length is not the expected type, validation failed.") obj.metric_id&.is_a?(String) != false || raise("Passed value for field obj.metric_id is not the expected type, validation failed.") obj.metric_value&.is_a?(Float) != false || raise("Passed value for field obj.metric_value is not the expected type, validation failed.") obj.metric_name&.is_a?(String) != false || raise("Passed value for field obj.metric_name is not the expected type, validation failed.") obj.current_streak.nil? || TrophyApiClient::MetricEventStreakResponse.validate_raw(obj: obj.current_streak) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of AchievementResponse to a JSON object
136 137 138 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 136 def to_json(*_args) @_field_set&.to_json end |