Class: TrophyApiClient::AchievementResponse
- Inherits:
-
Object
- Object
- TrophyApiClient::AchievementResponse
- Defined in:
- lib/trophy_api_client/types/achievement_response.rb
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::AchievementResponse
Deserialize a JSON object to an instance of AchievementResponse.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::AchievementResponse
Deserialize a JSON object to an instance of AchievementResponse
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 14 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) begin TrophyApiClient::MetricAchievementResponse.validate_raw(obj: struct) return TrophyApiClient::MetricAchievementResponse.from_json(json_object: struct) unless struct.nil? return nil rescue StandardError # noop end begin TrophyApiClient::StreakAchievementResponse.validate_raw(obj: struct) return TrophyApiClient::StreakAchievementResponse.from_json(json_object: struct) unless struct.nil? return nil rescue StandardError # noop end begin TrophyApiClient::ApiAchievementResponse.validate_raw(obj: struct) return TrophyApiClient::ApiAchievementResponse.from_json(json_object: struct) unless struct.nil? return nil rescue StandardError # noop end struct end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/trophy_api_client/types/achievement_response.rb', line 49 def self.validate_raw(obj:) begin return TrophyApiClient::MetricAchievementResponse.validate_raw(obj: obj) rescue StandardError # noop end begin return TrophyApiClient::StreakAchievementResponse.validate_raw(obj: obj) rescue StandardError # noop end begin return TrophyApiClient::ApiAchievementResponse.validate_raw(obj: obj) rescue StandardError # noop end raise("Passed value matched no type within the union, validation failed.") end |