Class: TrophyApiClient::AchievementWithStatsResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/trophy_api_client/types/achievement_with_stats_response.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id:, name:, trigger:, completions: OMIT, completed_percentage: OMIT, description: OMIT, badge_url: OMIT, key: OMIT, streak_length: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, additional_properties: nil) ⇒ TrophyApiClient::AchievementWithStatsResponse

Parameters:

  • completions (Integer) (defaults to: OMIT)

    The number of users who have completed this achievement.

  • completed_percentage (Float) (defaults to: OMIT)

    The percentage of all users who have completed this achievement.

  • id (String)

    The unique ID of the achievement.

  • name (String)

    The name of this achievement.

  • trigger (String)

    The trigger of the achievement, either ‘metric’, ‘streak’, or ‘api’.

  • description (String) (defaults to: OMIT)

    The description of this achievement.

  • badge_url (String) (defaults to: OMIT)

    The URL of the badge image for the achievement, if one has been uploaded.

  • key (String) (defaults to: OMIT)

    The key used to reference this achievement in the API (only applicable if trigger = ‘api’)

  • streak_length (Integer) (defaults to: OMIT)

    The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’)

  • metric_id (String) (defaults to: OMIT)

    The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’)

  • metric_value (Float) (defaults to: OMIT)

    The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’)

  • metric_name (String) (defaults to: OMIT)

    The name of the metric associated with this achievement (only applicable if trigger = ‘metric’)

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 64

def initialize(id:, name:, trigger:, completions: OMIT, completed_percentage: OMIT, description: OMIT,
               badge_url: OMIT, key: OMIT, streak_length: OMIT, metric_id: OMIT, metric_value: OMIT, metric_name: OMIT, additional_properties: nil)
  @completions = completions if completions != OMIT
  @completed_percentage = completed_percentage if completed_percentage != OMIT
  @id = id
  @name = name
  @trigger = trigger
  @description = description if description != OMIT
  @badge_url = badge_url if badge_url != OMIT
  @key = key if key != OMIT
  @streak_length = streak_length if streak_length != OMIT
  @metric_id = metric_id if metric_id != OMIT
  @metric_value = metric_value if metric_value != OMIT
  @metric_name = metric_name if metric_name != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "completions": completions,
    "completedPercentage": completed_percentage,
    "id": id,
    "name": name,
    "trigger": trigger,
    "description": description,
    "badgeUrl": badge_url,
    "key": key,
    "streakLength": streak_length,
    "metricId": metric_id,
    "metricValue": metric_value,
    "metricName": metric_name
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



38
39
40
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 38

def additional_properties
  @additional_properties
end

#badge_urlString (readonly)

Returns The URL of the badge image for the achievement, if one has been uploaded.

Returns:

  • (String)

    The URL of the badge image for the achievement, if one has been uploaded.



21
22
23
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 21

def badge_url
  @badge_url
end

#completed_percentageFloat (readonly)

Returns The percentage of all users who have completed this achievement.

Returns:

  • (Float)

    The percentage of all users who have completed this achievement.



11
12
13
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 11

def completed_percentage
  @completed_percentage
end

#completionsInteger (readonly)

Returns The number of users who have completed this achievement.

Returns:

  • (Integer)

    The number of users who have completed this achievement.



9
10
11
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 9

def completions
  @completions
end

#descriptionString (readonly)

Returns The description of this achievement.

Returns:

  • (String)

    The description of this achievement.



19
20
21
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 19

def description
  @description
end

#idString (readonly)

Returns The unique ID of the achievement.

Returns:

  • (String)

    The unique ID of the achievement.



13
14
15
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 13

def id
  @id
end

#keyString (readonly)

Returns The key used to reference this achievement in the API (only applicable if trigger = ‘api’).

Returns:

  • (String)

    The key used to reference this achievement in the API (only applicable if trigger = ‘api’)



24
25
26
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 24

def key
  @key
end

#metric_idString (readonly)

Returns The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’).

Returns:

  • (String)

    The ID of the metric associated with this achievement (only applicable if trigger = ‘metric’)



30
31
32
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 30

def metric_id
  @metric_id
end

#metric_nameString (readonly)

Returns The name of the metric associated with this achievement (only applicable if trigger = ‘metric’).

Returns:

  • (String)

    The name of the metric associated with this achievement (only applicable if trigger = ‘metric’)



36
37
38
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 36

def metric_name
  @metric_name
end

#metric_valueFloat (readonly)

Returns The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’).

Returns:

  • (Float)

    The value of the metric required to complete the achievement (only applicable if trigger = ‘metric’)



33
34
35
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 33

def metric_value
  @metric_value
end

#nameString (readonly)

Returns The name of this achievement.

Returns:

  • (String)

    The name of this achievement.



15
16
17
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 15

def name
  @name
end

#streak_lengthInteger (readonly)

Returns The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’).

Returns:

  • (Integer)

    The length of the streak required to complete the achievement (only applicable if trigger = ‘streak’)



27
28
29
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 27

def streak_length
  @streak_length
end

#triggerString (readonly)

Returns The trigger of the achievement, either ‘metric’, ‘streak’, or ‘api’.

Returns:

  • (String)

    The trigger of the achievement, either ‘metric’, ‘streak’, or ‘api’.



17
18
19
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 17

def trigger
  @trigger
end

Class Method Details

.from_json(json_object:) ⇒ TrophyApiClient::AchievementWithStatsResponse

Deserialize a JSON object to an instance of AchievementWithStatsResponse

Parameters:

  • json_object (String)

Returns:



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 101

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  completions = parsed_json["completions"]
  completed_percentage = parsed_json["completedPercentage"]
  id = parsed_json["id"]
  name = parsed_json["name"]
  trigger = parsed_json["trigger"]
  description = parsed_json["description"]
  badge_url = parsed_json["badgeUrl"]
  key = parsed_json["key"]
  streak_length = parsed_json["streakLength"]
  metric_id = parsed_json["metricId"]
  metric_value = parsed_json["metricValue"]
  metric_name = parsed_json["metricName"]
  new(
    completions: completions,
    completed_percentage: completed_percentage,
    id: id,
    name: name,
    trigger: trigger,
    description: description,
    badge_url: badge_url,
    key: key,
    streak_length: streak_length,
    metric_id: metric_id,
    metric_value: metric_value,
    metric_name: metric_name,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 146

def self.validate_raw(obj:)
  obj.completions&.is_a?(Integer) != false || raise("Passed value for field obj.completions is not the expected type, validation failed.")
  obj.completed_percentage&.is_a?(Float) != false || raise("Passed value for field obj.completed_percentage is not the expected type, validation failed.")
  obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.trigger.is_a?(String) != false || raise("Passed value for field obj.trigger is not the expected type, validation failed.")
  obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.")
  obj.badge_url&.is_a?(String) != false || raise("Passed value for field obj.badge_url is not the expected type, validation failed.")
  obj.key&.is_a?(String) != false || raise("Passed value for field obj.key is not the expected type, validation failed.")
  obj.streak_length&.is_a?(Integer) != false || raise("Passed value for field obj.streak_length is not the expected type, validation failed.")
  obj.metric_id&.is_a?(String) != false || raise("Passed value for field obj.metric_id is not the expected type, validation failed.")
  obj.metric_value&.is_a?(Float) != false || raise("Passed value for field obj.metric_value is not the expected type, validation failed.")
  obj.metric_name&.is_a?(String) != false || raise("Passed value for field obj.metric_name is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of AchievementWithStatsResponse to a JSON object

Returns:

  • (String)


136
137
138
# File 'lib/trophy_api_client/types/achievement_with_stats_response.rb', line 136

def to_json(*_args)
  @_field_set&.to_json
end