Class: TrophyApiClient::AsyncStreaksClient
- Inherits:
-
Object
- Object
- TrophyApiClient::AsyncStreaksClient
- Defined in:
- lib/trophy_api_client/streaks/client.rb
Instance Attribute Summary collapse
Instance Method Summary collapse
- #initialize(request_client:) ⇒ TrophyApiClient::AsyncStreaksClient constructor
-
#list(user_ids: nil, request_options: nil) ⇒ TrophyApiClient::BULK_STREAK_RESPONSE
Get the streak lengths of a list of users, ranked by streak length from longest to shortest.
-
#rankings(limit: nil, type: nil, request_options: nil) ⇒ Array<TrophyApiClient::StreakRankingUser>
Get the top users by streak length (active or longest).
Constructor Details
#initialize(request_client:) ⇒ TrophyApiClient::AsyncStreaksClient
100 101 102 |
# File 'lib/trophy_api_client/streaks/client.rb', line 100 def initialize(request_client:) @request_client = request_client end |
Instance Attribute Details
#request_client ⇒ TrophyApiClient::AsyncRequestClient (readonly)
96 97 98 |
# File 'lib/trophy_api_client/streaks/client.rb', line 96 def request_client @request_client end |
Instance Method Details
#list(user_ids: nil, request_options: nil) ⇒ TrophyApiClient::BULK_STREAK_RESPONSE
Get the streak lengths of a list of users, ranked by streak length from longest
to shortest.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/trophy_api_client/streaks/client.rb', line 117 def list(user_ids: nil, request_options: nil) Async do response = @request_client.conn.get do |req| req..timeout = .timeout_in_seconds unless &.timeout_in_seconds.nil? req.headers["X-API-KEY"] = .api_key unless &.api_key.nil? req.headers["Tenant-ID"] = .tenant_id unless &.tenant_id.nil? req.headers = { **(req.headers || {}), **@request_client.get_headers, **(&.additional_headers || {}) }.compact req.params = { **(&.additional_query_parameters || {}), "userIds": user_ids }.compact unless .nil? || &.additional_body_parameters.nil? req.body = { **(&.additional_body_parameters || {}) }.compact end req.url "#{@request_client.get_url(environment: api, request_options: )}/streaks" end parsed_json = JSON.parse(response.body) parsed_json&.map do |item| item = item.to_json TrophyApiClient::BulkStreakResponseItem.from_json(json_object: item) end end end |
#rankings(limit: nil, type: nil, request_options: nil) ⇒ Array<TrophyApiClient::StreakRankingUser>
Get the top users by streak length (active or longest).
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/trophy_api_client/streaks/client.rb', line 155 def rankings(limit: nil, type: nil, request_options: nil) Async do response = @request_client.conn.get do |req| req..timeout = .timeout_in_seconds unless &.timeout_in_seconds.nil? req.headers["X-API-KEY"] = .api_key unless &.api_key.nil? req.headers["Tenant-ID"] = .tenant_id unless &.tenant_id.nil? req.headers = { **(req.headers || {}), **@request_client.get_headers, **(&.additional_headers || {}) }.compact req.params = { **(&.additional_query_parameters || {}), "limit": limit, "type": type }.compact unless .nil? || &.additional_body_parameters.nil? req.body = { **(&.additional_body_parameters || {}) }.compact end req.url "#{@request_client.get_url(environment: api, request_options: )}/streaks/rankings" end parsed_json = JSON.parse(response.body) parsed_json&.map do |item| item = item.to_json TrophyApiClient::StreakRankingUser.from_json(json_object: item) end end end |