Class: TrophyApiClient::CreateLeaderboardRequestItemStatus
- Inherits:
-
Object
- Object
- TrophyApiClient::CreateLeaderboardRequestItemStatus
- Defined in:
- lib/trophy_api_client/types/create_leaderboard_request_item_status.rb
Overview
The initial user-facing status. Defaults to ‘inactive`. Use `scheduled` for
leaderboards that should be active in the future and `finished` only when
creating a leaderboard with an end date in the past.
Constant Summary collapse
- INACTIVE =
"inactive"- ACTIVE =
"active"- SCHEDULED =
"scheduled"- FINISHED =
"finished"