Class: TrophyApiClient::DeletePointsBoostsResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/trophy_api_client/types/delete_points_boosts_response.rb

Overview

Response containing the points boosts that were archived and any per-item

issues.

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(deleted:, issues:, additional_properties: nil) ⇒ TrophyApiClient::DeletePointsBoostsResponse

Parameters:

  • deleted (Array<TrophyApiClient::DeletedResource>)

    Array of archived points boosts represented by ID.

  • issues (Array<TrophyApiClient::AdminIssue>)

    Array of issues encountered during boost archival.

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



28
29
30
31
32
33
# File 'lib/trophy_api_client/types/delete_points_boosts_response.rb', line 28

def initialize(deleted:, issues:, additional_properties: nil)
  @deleted = deleted
  @issues = issues
  @additional_properties = additional_properties
  @_field_set = { "deleted": deleted, "issues": issues }
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



17
18
19
# File 'lib/trophy_api_client/types/delete_points_boosts_response.rb', line 17

def additional_properties
  @additional_properties
end

#deletedArray<TrophyApiClient::DeletedResource> (readonly)

Returns Array of archived points boosts represented by ID.

Returns:



13
14
15
# File 'lib/trophy_api_client/types/delete_points_boosts_response.rb', line 13

def deleted
  @deleted
end

#issuesArray<TrophyApiClient::AdminIssue> (readonly)

Returns Array of issues encountered during boost archival.

Returns:



15
16
17
# File 'lib/trophy_api_client/types/delete_points_boosts_response.rb', line 15

def issues
  @issues
end

Class Method Details

.from_json(json_object:) ⇒ TrophyApiClient::DeletePointsBoostsResponse

Deserialize a JSON object to an instance of DeletePointsBoostsResponse

Parameters:

  • json_object (String)

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/trophy_api_client/types/delete_points_boosts_response.rb', line 39

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  deleted = parsed_json["deleted"]&.map do |item|
    item = item.to_json
    TrophyApiClient::DeletedResource.from_json(json_object: item)
  end
  issues = parsed_json["issues"]&.map do |item|
    item = item.to_json
    TrophyApiClient::AdminIssue.from_json(json_object: item)
  end
  new(
    deleted: deleted,
    issues: issues,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


70
71
72
73
# File 'lib/trophy_api_client/types/delete_points_boosts_response.rb', line 70

def self.validate_raw(obj:)
  obj.deleted.is_a?(Array) != false || raise("Passed value for field obj.deleted is not the expected type, validation failed.")
  obj.issues.is_a?(Array) != false || raise("Passed value for field obj.issues is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of DeletePointsBoostsResponse to a JSON object

Returns:

  • (String)


60
61
62
# File 'lib/trophy_api_client/types/delete_points_boosts_response.rb', line 60

def to_json(*_args)
  @_field_set&.to_json
end