Class: TrophyApiClient::GetUserPointsResponse
- Inherits:
-
Object
- Object
- TrophyApiClient::GetUserPointsResponse
- Defined in:
- lib/trophy_api_client/types/get_user_points_response.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#awards ⇒ Array<TrophyApiClient::PointsAward>
readonly
Array of trigger awards that added points.
-
#total ⇒ Float
readonly
The user’s total points.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::GetUserPointsResponse
Deserialize a JSON object to an instance of GetUserPointsResponse.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(total: OMIT, awards: OMIT, additional_properties: nil) ⇒ TrophyApiClient::GetUserPointsResponse constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of GetUserPointsResponse to a JSON object.
Constructor Details
#initialize(total: OMIT, awards: OMIT, additional_properties: nil) ⇒ TrophyApiClient::GetUserPointsResponse
25 26 27 28 29 30 31 32 |
# File 'lib/trophy_api_client/types/get_user_points_response.rb', line 25 def initialize(total: OMIT, awards: OMIT, additional_properties: nil) @total = total if total != OMIT @awards = awards if awards != OMIT @additional_properties = additional_properties @_field_set = { "total": total, "awards": awards }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
14 15 16 |
# File 'lib/trophy_api_client/types/get_user_points_response.rb', line 14 def additional_properties @additional_properties end |
#awards ⇒ Array<TrophyApiClient::PointsAward> (readonly)
Returns Array of trigger awards that added points.
12 13 14 |
# File 'lib/trophy_api_client/types/get_user_points_response.rb', line 12 def awards @awards end |
#total ⇒ Float (readonly)
Returns The user’s total points.
10 11 12 |
# File 'lib/trophy_api_client/types/get_user_points_response.rb', line 10 def total @total end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::GetUserPointsResponse
Deserialize a JSON object to an instance of GetUserPointsResponse
38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/trophy_api_client/types/get_user_points_response.rb', line 38 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) total = parsed_json["total"] awards = parsed_json["awards"]&.map do |item| item = item.to_json TrophyApiClient::PointsAward.from_json(json_object: item) end new( total: total, awards: awards, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
66 67 68 69 |
# File 'lib/trophy_api_client/types/get_user_points_response.rb', line 66 def self.validate_raw(obj:) obj.total&.is_a?(Float) != false || raise("Passed value for field obj.total is not the expected type, validation failed.") obj.awards&.is_a?(Array) != false || raise("Passed value for field obj.awards is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of GetUserPointsResponse to a JSON object
56 57 58 |
# File 'lib/trophy_api_client/types/get_user_points_response.rb', line 56 def to_json(*_args) @_field_set&.to_json end |