Class: TrophyApiClient::MetricEventPointsResponse
- Inherits:
-
Object
- Object
- TrophyApiClient::MetricEventPointsResponse
- Defined in:
- lib/trophy_api_client/types/metric_event_points_response.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#added ⇒ Float
readonly
The points added by this event.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#awards ⇒ Array<TrophyApiClient::PointsAward>
readonly
Array of trigger awards that added points.
-
#badge_url ⇒ String
readonly
The URL of the badge image for the points system.
-
#description ⇒ String
readonly
The description of the points system.
-
#id ⇒ String
readonly
The ID of the points system.
-
#name ⇒ String
readonly
The name of the points system.
-
#total ⇒ Float
readonly
The user’s total points.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::MetricEventPointsResponse
Deserialize a JSON object to an instance of MetricEventPointsResponse.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(id:, name:, total:, awards:, added: OMIT, description: OMIT, badge_url: OMIT, additional_properties: nil) ⇒ TrophyApiClient::MetricEventPointsResponse constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of MetricEventPointsResponse to a JSON object.
Constructor Details
#initialize(id:, name:, total:, awards:, added: OMIT, description: OMIT, badge_url: OMIT, additional_properties: nil) ⇒ TrophyApiClient::MetricEventPointsResponse
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 40 def initialize(id:, name:, total:, awards:, added: OMIT, description: OMIT, badge_url: OMIT, additional_properties: nil) @added = added if added != OMIT @id = id @name = name @description = description if description != OMIT @badge_url = badge_url if badge_url != OMIT @total = total @awards = awards @additional_properties = additional_properties @_field_set = { "added": added, "id": id, "name": name, "description": description, "badgeUrl": badge_url, "total": total, "awards": awards }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#added ⇒ Float (readonly)
Returns The points added by this event.
10 11 12 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 10 def added @added end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
24 25 26 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 24 def additional_properties @additional_properties end |
#awards ⇒ Array<TrophyApiClient::PointsAward> (readonly)
Returns Array of trigger awards that added points.
22 23 24 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 22 def awards @awards end |
#badge_url ⇒ String (readonly)
Returns The URL of the badge image for the points system.
18 19 20 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 18 def badge_url @badge_url end |
#description ⇒ String (readonly)
Returns The description of the points system.
16 17 18 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 16 def description @description end |
#id ⇒ String (readonly)
Returns The ID of the points system.
12 13 14 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 12 def id @id end |
#name ⇒ String (readonly)
Returns The name of the points system.
14 15 16 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 14 def name @name end |
#total ⇒ Float (readonly)
Returns The user’s total points.
20 21 22 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 20 def total @total end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::MetricEventPointsResponse
Deserialize a JSON object to an instance of MetricEventPointsResponse
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 67 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) added = parsed_json["added"] id = parsed_json["id"] name = parsed_json["name"] description = parsed_json["description"] badge_url = parsed_json["badgeUrl"] total = parsed_json["total"] awards = parsed_json["awards"]&.map do |item| item = item.to_json TrophyApiClient::PointsAward.from_json(json_object: item) end new( added: added, id: id, name: name, description: description, badge_url: badge_url, total: total, awards: awards, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
105 106 107 108 109 110 111 112 113 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 105 def self.validate_raw(obj:) obj.added&.is_a?(Float) != false || raise("Passed value for field obj.added is not the expected type, validation failed.") obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.badge_url&.is_a?(String) != false || raise("Passed value for field obj.badge_url is not the expected type, validation failed.") obj.total.is_a?(Float) != false || raise("Passed value for field obj.total is not the expected type, validation failed.") obj.awards.is_a?(Array) != false || raise("Passed value for field obj.awards is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of MetricEventPointsResponse to a JSON object
95 96 97 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 95 def to_json(*_args) @_field_set&.to_json end |