Class: TrophyApiClient::MetricEventPointsResponse
- Inherits:
-
Object
- Object
- TrophyApiClient::MetricEventPointsResponse
- Defined in:
- lib/trophy_api_client/types/metric_event_points_response.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#added ⇒ Float
readonly
The points added by this event.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#awards ⇒ Array<TrophyApiClient::PointsAward>
readonly
Array of trigger awards that added points.
-
#total ⇒ Float
readonly
The user’s total points.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::MetricEventPointsResponse
Deserialize a JSON object to an instance of MetricEventPointsResponse.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(added: OMIT, total: OMIT, awards: OMIT, additional_properties: nil) ⇒ TrophyApiClient::MetricEventPointsResponse constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of MetricEventPointsResponse to a JSON object.
Constructor Details
#initialize(added: OMIT, total: OMIT, awards: OMIT, additional_properties: nil) ⇒ TrophyApiClient::MetricEventPointsResponse
28 29 30 31 32 33 34 35 36 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 28 def initialize(added: OMIT, total: OMIT, awards: OMIT, additional_properties: nil) @added = added if added != OMIT @total = total if total != OMIT @awards = awards if awards != OMIT @additional_properties = additional_properties @_field_set = { "added": added, "total": total, "awards": awards }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#added ⇒ Float (readonly)
Returns The points added by this event.
10 11 12 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 10 def added @added end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
16 17 18 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 16 def additional_properties @additional_properties end |
#awards ⇒ Array<TrophyApiClient::PointsAward> (readonly)
Returns Array of trigger awards that added points.
14 15 16 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 14 def awards @awards end |
#total ⇒ Float (readonly)
Returns The user’s total points.
12 13 14 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 12 def total @total end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::MetricEventPointsResponse
Deserialize a JSON object to an instance of MetricEventPointsResponse
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 42 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) added = parsed_json["added"] total = parsed_json["total"] awards = parsed_json["awards"]&.map do |item| item = item.to_json TrophyApiClient::PointsAward.from_json(json_object: item) end new( added: added, total: total, awards: awards, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
72 73 74 75 76 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 72 def self.validate_raw(obj:) obj.added&.is_a?(Float) != false || raise("Passed value for field obj.added is not the expected type, validation failed.") obj.total&.is_a?(Float) != false || raise("Passed value for field obj.total is not the expected type, validation failed.") obj.awards&.is_a?(Array) != false || raise("Passed value for field obj.awards is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of MetricEventPointsResponse to a JSON object
62 63 64 |
# File 'lib/trophy_api_client/types/metric_event_points_response.rb', line 62 def to_json(*_args) @_field_set&.to_json end |