Class: TrophyApiClient::StreakResponse
- Inherits:
-
Object
- Object
- TrophyApiClient::StreakResponse
- Defined in:
- lib/trophy_api_client/types/streak_response.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#frequency ⇒ TrophyApiClient::StreakFrequency
readonly
The frequency of the streak.
-
#length ⇒ Integer
readonly
The length of the user’s current streak.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::StreakResponse
Deserialize a JSON object to an instance of StreakResponse.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(length:, frequency:, additional_properties: nil) ⇒ TrophyApiClient::StreakResponse constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of StreakResponse to a JSON object.
Constructor Details
#initialize(length:, frequency:, additional_properties: nil) ⇒ TrophyApiClient::StreakResponse
25 26 27 28 29 30 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 25 def initialize(length:, frequency:, additional_properties: nil) @length = length @frequency = frequency @additional_properties = additional_properties @_field_set = { "length": length, "frequency": frequency } end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
14 15 16 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 14 def additional_properties @additional_properties end |
#frequency ⇒ TrophyApiClient::StreakFrequency (readonly)
Returns The frequency of the streak.
12 13 14 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 12 def frequency @frequency end |
#length ⇒ Integer (readonly)
Returns The length of the user’s current streak.
10 11 12 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 10 def length @length end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::StreakResponse
Deserialize a JSON object to an instance of StreakResponse
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 36 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) length = parsed_json["length"] frequency = parsed_json["frequency"] new( length: length, frequency: frequency, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
61 62 63 64 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 61 def self.validate_raw(obj:) obj.length.is_a?(Integer) != false || raise("Passed value for field obj.length is not the expected type, validation failed.") obj.frequency.is_a?(TrophyApiClient::StreakFrequency) != false || raise("Passed value for field obj.frequency is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of StreakResponse to a JSON object
51 52 53 |
# File 'lib/trophy_api_client/types/streak_response.rb', line 51 def to_json(*_args) @_field_set&.to_json end |