Class: TrophyApiClient::UpdatePointsSystemRequestItem
- Inherits:
-
Object
- Object
- TrophyApiClient::UpdatePointsSystemRequestItem
- Defined in:
- lib/trophy_api_client/types/update_points_system_request_item.rb
Overview
A points system update object. Only id is required; all other fields are
optional.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#badge ⇒ TrophyApiClient::UpdatePointsSystemRequestItemBadge
readonly
Updated badge.
-
#description ⇒ String
readonly
Updated description.
-
#id ⇒ String
readonly
The UUID of the points system to update.
-
#max_points ⇒ Integer
readonly
Updated max points.
-
#name ⇒ String
readonly
Updated name.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ TrophyApiClient::UpdatePointsSystemRequestItem
Deserialize a JSON object to an instance of UpdatePointsSystemRequestItem.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(id:, name: OMIT, description: OMIT, badge: OMIT, max_points: OMIT, additional_properties: nil) ⇒ TrophyApiClient::UpdatePointsSystemRequestItem constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of UpdatePointsSystemRequestItem to a JSON object.
Constructor Details
#initialize(id:, name: OMIT, description: OMIT, badge: OMIT, max_points: OMIT, additional_properties: nil) ⇒ TrophyApiClient::UpdatePointsSystemRequestItem
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 36 def initialize(id:, name: OMIT, description: OMIT, badge: OMIT, max_points: OMIT, additional_properties: nil) @id = id @name = name if name != OMIT @description = description if description != OMIT @badge = badge if badge != OMIT @max_points = max_points if max_points != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "name": name, "description": description, "badge": badge, "maxPoints": max_points }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
22 23 24 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 22 def additional_properties @additional_properties end |
#badge ⇒ TrophyApiClient::UpdatePointsSystemRequestItemBadge (readonly)
Returns Updated badge. Set to null to remove.
18 19 20 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 18 def badge @badge end |
#description ⇒ String (readonly)
Returns Updated description.
16 17 18 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 16 def description @description end |
#id ⇒ String (readonly)
Returns The UUID of the points system to update.
12 13 14 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 12 def id @id end |
#max_points ⇒ Integer (readonly)
Returns Updated max points. Set to null to remove.
20 21 22 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 20 def max_points @max_points end |
#name ⇒ String (readonly)
Returns Updated name.
14 15 16 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 14 def name @name end |
Class Method Details
.from_json(json_object:) ⇒ TrophyApiClient::UpdatePointsSystemRequestItem
Deserialize a JSON object to an instance of UpdatePointsSystemRequestItem
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 58 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] name = parsed_json["name"] description = parsed_json["description"] if parsed_json["badge"].nil? badge = nil else badge = parsed_json["badge"].to_json badge = TrophyApiClient::UpdatePointsSystemRequestItemBadge.from_json(json_object: badge) end max_points = parsed_json["maxPoints"] new( id: id, name: name, description: description, badge: badge, max_points: max_points, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
94 95 96 97 98 99 100 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 94 def self.validate_raw(obj:) obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.badge.nil? || TrophyApiClient::UpdatePointsSystemRequestItemBadge.validate_raw(obj: obj.badge) obj.max_points&.is_a?(Integer) != false || raise("Passed value for field obj.max_points is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of UpdatePointsSystemRequestItem to a JSON object
84 85 86 |
# File 'lib/trophy_api_client/types/update_points_system_request_item.rb', line 84 def to_json(*_args) @_field_set&.to_json end |